# Gabriel Client

Stream data back and forth between Gabriel Server

## Installation
Requires Python >= 3.6

Run `pip install gabriel-client`

## Publishing Changes to PyPi

Update the version number in setup.py. Then follow [these instructions](https://packaging.python.org/tutorials/packaging-projects/#generating-distribution-archives).